function CPN = CCP( LCP )
% CCP allows user to change some control parameters during run-time
%   LCP is the local copy of the structure cp containing the parameters
%   CPN is the changed structure returned to the calling function
%   Made into a separate function, PT, 23 July 2015
%   Updated 4 Sep 2015, and 5 Oct 2015, PT

fprintf('%s\n', '- - - - - CHANGE CONTROL PARAMETERS - - - - -');
fprintf('%s\n', 'Most control parameters for are set in cf3.m');
fprintf('%s\n', 'You can change some of these parameters here,');
fprintf('%s\n', '  without altering the contents of cf3;');
fprintf('%s\n', '  current values are shown as [default];');
fprintf('%s\n', '  press <RET> alone to confirm.');
fprintf('\n');
%
fprintf('%s\n', '--- the parameter mf:');
fprintf('%s\n', '        controls data selection:');
fprintf('%s\n', '        mf = 0 --> select all data');
fprintf('%s\n', '        mf = 1 --> month-average data');
fprintf('%s\n', '        mf = 2 --> month-average data (arith)');
fprintf('%s\n', '        mf < 0 --> randomly select 1 in -mf');
LCP.mf = getnum('--- confirm or change the value of mf', LCP.mf);
fprintf('\n');
% --- next added 9 Aug 09
fprintf('%s\n', '--- the parameter p:');
fprintf('%s\n', '        controls envelope outlier exclusion:');
fprintf('%s\n', '        p = 1 --> all data used for envelope');
fprintf('%s\n', '        p = 0.5 to 0.99 --> exclude (1-p)');
LCP.p = getnum('--- confirm or change the value of p', LCP.p);
fprintf('\n');
%
% --- next added 5 Oct 13
fprintf('%s\n', '--- the parameter sc:');
fprintf('%s\n', '        controls envelope axis scaling:');
fprintf('%s\n', '        sc = 1 --> axis scaling ON');
fprintf('%s\n', '        sc = 0 --> axis scaling OFF');
LCP.sc = getnum('--- confirm or change the value of sc', LCP.sc);
fprintf('\n');
%
% next added 7 Oct 13
fprintf('%s\n', '--- reference period:');
LCP.refs = getnum('--- confirm or change the start year', LCP.refs);
LCP.refe = getnum('--- confirm or change the end year', LCP.refe);
if LCP.refe < LCP.refs, LCP.refe = LCP.refs; 
    fprintf('%s %u \n', ' ** corrected end year to ', LCP.refe); end
fprintf('\n');
% IF VALUES HAVE BEEN CHANGED, SHOULD, AFTER WARNING, DELETE OLD REF ENV
%
% next added 24 July 2015
fprintf('%s\n', '--- the parameter COL:');
fprintf('%s\n', '        controls colour and amount of detail:');
fprintf('%s\n', '        COL = 1 --> colour graphics and much text');
fprintf('%s\n', '        COL = 0 --> B&W graphics and little text');
LCP.COL = getnum('--- confirm or change the value of COL', LCP.COL);
fprintf('\n');
%
% next added 4 Sep 2015
% NB - WHERE ARE MAXN AND MAXB CALCULATED?
fprintf('%s\n', '--- the maximum value for the axes in a PI diagram:');
if LCP.c1svt1 < 1.5, % is cell numbers
    fprintf('%s\n', '                            as log10(cells\L):');
    LCP.nmax= getnum('--- confirm or change the value of nmax', LCP.nmax);
    if LCP.maxn > LCP.nmax, fprintf('%s %5.2f \n', ...
        ' ** warning: observed max log10(cells/L) in complete TS =  ', ...
            LCP.maxn); 
    end
else % is biolvolume
    fprintf('%s\n', '                 as biovolume log10(mm3\L):');
    LCP.bmax= getnum('--- confirm or change the value of bmax', LCP.bmax);
    if LCP.maxb > LCP.bmax, fprintf('%s %5.2f \n', ...
        ' ** warning: observed max log10(mm3\L) in complete TS =  ', ...
            LCP.maxb); 
    end
end 
fprintf('\n');
%
% next added 8 May 2016
fprintf('%s\n', '--- the parameters z in log10(Y + z):');
if LCP.c1svt1 < 1.5, % is numbers
    fprintf('%s\n', '                            as log10(numbers):');
LCP.z1 = getnum('--- confirm or change the value of z1', LCP.z1);
LCP.z2 = getnum('--- confirm or change the value of z2', LCP.z2);
else % is biolvolume
    fprintf('%s\n', '                         as log10 (biovolume):');
LCP.bz1 = getnum('--- confirm or change the value of z1', LCP.bz1);
LCP.bz2 = getnum('--- confirm or change the value of z2', LCP.bz2);
end
fprintf('\n');

% need to change number of iterations ?
%
fprintf('%s\n', ...
    'Quit the run and edit cf4.m to change other parameters if needed');
fprintf('%s\n\n', '- - - - - - - - - - - - - - - - - - - - - - - -');

CPN = LCP; % output updated parameter structure
end

