function [ y, yr, ydev, kend ] = TStrend( datx, daty, degp )
% TSTREND calculates Kendall tau and fits a polynomial to time-series data
%   PT, 13-14 Oct 2015
%   INPUT
%       datx = column vector of independent variable (all reals)
%       daty = column vector of dependent variable (of the same length)
%                   (may contain NaNs)
%       degp = (initial) degree of polyomial to be fitted
%   OUTPUT
%   The polynomial is  y = poly(yr), thus
%       y = column vector of values predicted at non-NanN values of datax 
%           using the fitted polynomial
%       yr = vector of years (or other time-interval)
%       ydev = vector of deviations in y (observed - fitted)
%       kend = structure (with fields .tau and .prob) from Kendall calc.

ts = daty(isfinite(daty)); % removes NaNs in daty values
yr = datx(isfinite(daty)); % removes corresponding datax values
kend = Kendl1(yr, ts);% call the Kendall function (check MANN-KENDALL)
if kend.prob < 0.05, % time-series is significant, so
fprintf('--significant time-series with tau = %5.3f (prob = %6.4f )\n', ...
      kend.tau, kend.prob);
fprintf('-- order %u polynomial will be fitted and plotted \n', degp);
p = polyfit(yr,ts,degp); % NEEDS AN WARNING TRAP WITH REDUCTION OF DEGP
y = polyval(p,yr);
ydev = ts - y; 
else
    fprintf('--time-series not significant\n');
    y = NaN;
    ydev = NaN;
end
end

