% cf4.m: control file for Matlab PCI scripts from PCI1G
%
% Gives values to scalar or string variables
% contained in the structure cp, which serve to
% control the action of PCI scripts from PCI1ED3 onward
% In some cases the values are defaults, and can be changed
% dynamically in the main script.
%
% added new fields to set numbers or biomass: 13 June 2011, PT
% added new field to set scaling of axes when fitting envelope, 20 May 13
% added new fields to set default plot limits, 4 Sep 2015, PT
% restored2-file option, 29 Sep 2015, PT
%
% This script sets values when included in (called by) the main script
% % marks a comment and results in no action
% strings must be included in single quotes, e.g. 'text'
% numeric and string values can be changed
% BUT DO NOT EDIT VARIABLE NAMES!
% don't remove semicolons ---
%   (unless you want line result in command window)
%
% number of data files to be loaded (1 or 2) 
    cp.ndf = 1; % if 1, information about file 2 is ignored 
%
% Note: the data files must contain at least 3 columns of
%   (ASCII text) data, including 'date' (as year.dec) and
%   2 columns of (untransformed) state variable abundance
%
% information about data file 1
% name of data file (should include extension)
%    cp.df1n='L4.csv';
%    cp.df1n='B1B2.txt';
    cp.df1n = 'ptHPLF2edata1on7at16.txt';
 %       cp.df1n='Thau-TSDD.txt';
 %      cp.df1n='Thau_DDPP.txt'; % includes picoplankton
% description of data
%    cp.d1des='Northern North Sea';
    cp.d1des = 'Loch Creran';
%        cp.d1des = 'Thau lagoon';
% number of column to use for date values
    cp.c1dat=1;
% column number and description of first state variable
    cp.c1sv1=2;
    cp.dsv1='Si-users';
%    cp.dsv1 = 'diatoms';
 %   cp.dsv1 = 'picocyano';
% column number and description of second state variable
    cp.c1sv2=3;
    cp.dsv2='other autotrophs';
%   cp.dsv2 = 'dinoflagellates';   
%    cp.dsv2 = 'picoeukary';
% state variables are numbers (1) or biomass (2) (new Aug 09)
    cp.c1svt1 = 2;
    cp.c1svt2 = 2; % ** don't use this - must have consistency!
% file 1 SV data are to be transformed, log10(z+x)
%    cp.z1=0.0001;% min value for biomass as total cell volume
%    cp.z1=295; % Creran cell counts, 1970s
%    cp.z1 = 500; % value for CPR
% in next 4 rows' comments, 'col 1' = column specified by c1sv1 (etc)
    cp.z1 = 150; % min cells/L in col 1 - half obsv min of 300 cells/L dia
    cp.bz1 = 0.0001; % min value for biovolume (mm3/L) in column 1
    cp.z2 = 50; % min cells/L in col 2- half obs min of 100 cells/L dino
    cp.bz2 = 0.0001; % min value for biovolume (mm3/L) in column 2
% 4 Sep 2015: don't know if col 2 (z2 and bz2) values are used
% 
% ===== information about data file 2 (which may not be needed)
% data in file 2 must be comparable with data in file 1
% for example, file 1 cp.z and .bz will be used for both data sets
% name of data file 2 (should include extension)
    cp.df2n='ptHPLF2edata1on7at16.txt'; % same as file 1 - for testing!
% description of data
    cp.d2des='Creran loch (2)';
% number of column to use for date values
    cp.c2dat=1;
% column number of first state variable
    cp.c2sv1=2; % must be same as first SV from file 1
% column number and description of second state variable
    cp.c2sv2=3; % must be same as second SV from file 1
%
%
% selection information -- 
% set switch to select file for reference data
    cp.reff = 1; % either 1 or 2
    if cp.ndf < 1.5, cp.reff=1; end % ensure it's 1 if only one file
% first year of reference period (an integer)
   cp.refs=1979; % Creran
 %   cp.refs=2007; % Thau
%   cp.refs = 1987; % Thau
% last year of reference period (an integer; ---
%       all data from this year will be included)
    cp.refe=1981; % Creran
%    cp.refe = 2009; % Thau
%   cp.refe = 1989; % Thau
% set switch to select file for comparison data
    cp.compf = 2; % either 1 or 2
    if cp.ndf < 1.5, cp.compf=1; end % ensure it's 1 if only one file
% data aggregation or subsampling
% if mf is > 0.5, data are averaged over month
% if mf is < 0, data are chosen at random with probability of 1/-mf
% if mf = 0, all data are used
    cp.mf=0;
% set switch to apply mf to reference data as well as sample data
    cp.mfref = 1; % 1 = apply to reference also; 0 = don't apply
% set number of iterations for random subsampling when mf < 0
    cp.mfn=10;
% set fraction of data to be excluded from envelope (outliers are
%   1 - (p/2) at top and bottom of distribution
    cp.p = 0.9;
% set scaling of axes: 0 not scaling, 1 scaling on (used in FINDENV2)
    cp.sc = 1;
% set minimum number of values required for calculation of PI
    cp.mindata = 6;

% output information
%
    cp.COL = 1; % COL=0 sets black & white output with minimal text; 
    % COL > 0.5 uses colour and provides more text
    cp.pt='pdf';% saved graphics type; alternatives are 'ai', 'ps', 'pdf'
                % and others - see function PIPRINT
    cp.nmax = 7; % default upper limit (log10(cells/L)) for cell no. plot
                 % should not include space needed for text inserts
    cp.bmax = 1; % default upper limit (log10(mm3/L)) for biovolume plot
    cp.nmin = floor(log10(min(cp.z1,cp.z2))); % def.lower limit cell no.
    cp.bmin = floor(log10(min(cp.bz1,cp.bz2))); % ... biovolume
%
% seasonal selection
%       edit to allocate months to seasons for display in PI diagram
    cp.Winter = [1 2 12];
    cp.Spring = [3 4 5];
    cp.Summer = [6 7 8];
    cp.Autumn = [9 10 11];

% these values last updated
    cp.updated = '29 Sep 2015 by PT, loading same file twice';
%
% remainder of the file prints some information to the user
fprintf('%s\n', ...
    ['Inserted the control file cf4, which was updated ' cp.updated]);
fprintf('%s\n\n', ['Expecting ' num2str(cp.ndf) ' data file(s)']);
